import { getVideoImgUrl } from '@/utils';
import { CloseOutlined } from '@ant-design/icons';
import { Image, ImageProps, Modal, theme } from 'antd';
import React, { useState } from 'react';
import play from '../../../public/image/play.png';
import style from './index.less';

const VideoNews: React.FC<ImageProps> = ({ preview = false, src, ...data }) => {
  /*****************************/
  const { useToken } = theme;
  const { token } = useToken();
  const [toPlay, setToPlay] = useState<boolean>(false);
  /*****************************/

  return (
    <div style={{ display: 'inline-block' }}>
      <div className={style.imgNews} style={{ borderRadius: token.borderRadius }}>
        <Image
          src={src ? getVideoImgUrl(src) : 'error'}
          preview={false}
          {...data}
          className={style.img}
        />
        <div className={style.mask}>
          <img
            src={play}
            onClick={(e) => {
              e.stopPropagation();
              setToPlay(true);
            }}
          />
        </div>
      </div>
      {toPlay && (
        <div
          onClick={(e) => {
            e.stopPropagation();
          }}
        >
          <Modal
            open={toPlay}
            styles={{
              body: {
                backgroundColor: 'rgba(0,0,0,0.8)',
                overflow: 'hidden',
                borderRadius: token.borderRadius,
                padding: '20px 24px',
              },
            }}
            footer={null}
            closeIcon={<CloseOutlined style={{ color: token.colorPrimary }} />}
            onCancel={(e) => {
              e.stopPropagation();
              setToPlay(false);
            }}
            className="playVideo"
          >
            <video
              className={style.video}
              style={{ borderRadius: token.borderRadius }}
              src={src}
              autoPlay
              controls
              controlsList="nodownload"
            >
              您的浏览器不支持 video 标签。
            </video>
          </Modal>
        </div>
      )}
    </div>
  );
};

export default React.memo(VideoNews);
